#

##

##

    	escrow

    	summary

    		{
    			"petition": "send to escrow",
    			"freight": {
    				"from address": "EEC_448_2:...",
    				"to address": "EEC_448_2:...",
    				"amount": "",
    				"fee": ""
    			}
    		}

    		{
    			"petition": "receive from escrow",
    			"freight": {
    				"to address": "EEC_448_2:...",
    				"from": [{
    					"address": "EEC_448_2:...",
    					"amount": "",
    				},{
    					"address": "EEC_448_2:...",
    					"amount": "",
    				}],
    				"fee": ""
    			}
    		}

    	possibilities

    		{
    			"petition": "receive everything from escrow",
    			"freight": {
    				"to address": "EEC_448_2:...",
    				"fee": ""
    			}
    		}

    		send to escrow for a duration:
    			{
    				"petition": "send to escrow",
    				"freight": {
    					"from address": "EEC_448_2:...",
    					"to address": "EEC_448_2:...",
    					"duration": "",
    					"amount": "",
    					"fee": ""
    				}
    			}